@@ -216,6 +216,7 @@ class Read:
     def _opusBest(self):
         bOpus = re.findall('.*webm\s.*audio only.*', self.data) [-1]
         size = Read.size_check(self, bOpus, 'A')
+        qualito['best_opus'] = bOpus.split() [0]
         return size
     
     def _best(self):
@@ -267,6 +268,9 @@ class Read:
         bestV = re.findall('.*webm.*', self.data) [-1]
         size = Read.size_check(self, bestV, 'B')
         bestq = bestV.split() [3]
+        if bestq == 'DASH':
+            bestq = bestV.split() [2].split('x') [1]
+            bestq = f'{bestq}p'
         return [size, bestq]
 
 
@@ -315,15 +319,15 @@ def stream(link, quality, file, resume, playonly, fs):
     try:
         if playonly:
             rec     = ''
-            stream  = subprocess.run(['mpv', f'--ytdl-format={quality}/best', link, fs, resume, '--loop-playlist=no', rec, '--player-operation-mode=pseudo-gui'])
+            stream  = subprocess.run(['mpv', f'--ytdl-format={quality}/best', link, fs, resume, '--loop-playlist=no', rec, '--player-operation-mode=pseudo-gui', '--autofit-larger=30%'])
             if stream.returncode != 0:
                 print(''); menu.con_err()
             else:
-                print('\n')
+                print('')
             exit()
         else:
             rec     = f'--stream-record={file}'
-            stream  = subprocess.Popen(['mpv', f'--ytdl-format={quality}/best', link, fs, resume, '--loop-playlist=no', rec, '--player-operation-mode=pseudo-gui'])
+            stream  = subprocess.Popen(['mpv', f'--ytdl-format={quality}/best', link, fs, resume, '--loop-playlist=no', rec, '--player-operation-mode=pseudo-gui', '--autofit-larger=30%'])
 
             #WAITING..
             x = 0
@@ -340,14 +344,18 @@ def stream(link, quality, file, resume, playonly, fs):
             while x:
                 fsize = os.path.getsize(file)
                 fsize = round(fsize * 0.000001, 1)
-                print(f'\rSize = {fsize}(MB)', end='')
+                if fsize > 1000:
+                    fsize = round(fsize * 0.01, 2)
+                    print(f'\rSize: {fsize}(GB)', end='')
+                else:
+                    print(f'\rSize: {fsize}(MB)', end='')
                 if stream.poll() is not None:
                     print('\n')
                     x = False
 
     except KeyboardInterrupt:
         print(''); menu.usr_err()
-        if not playonly: stream.kill()
+        if not playonly: stream.terminate()
         exit()
 
 
