@@ -1,10 +1,13 @@
 # MENU by (Prayz Jomba)
-# last updated(18 Sep 2021) 04:43:28 PM
+# last updated(24 Oct 2021) 03:52:19 PM
 
 
 from rich.panel import Panel
 from rich.padding import Padding
+from rich.console import Console
 from rich import print as rprint
+rinput = Console().input
+from func_timeout import FunctionTimedOut, func_timeout
 
 
 # COLORS
@@ -72,7 +75,7 @@ def duration_asize(duration, aac, opus):
     s_aac = s(aac)
     s_opus = s(opus)
     duration = f'[{w}]DURATION:[/{w}][{ly}] ([i {lg}]{duration}[/i {lg}])[/{ly}]'
-    A = f'[{b}]AAC:[/{b}] [{lg}]{s_aac}[/{lg}]'
+    A = f'[{b}]M4A:[/{b}] [{lg}]{s_aac}[/{lg}]'
     O = f'[{aq}]OPUS:[/{aq}] [{lg}]{s_opus}[/{lg}]'
 
     #print(len(duration))
@@ -91,12 +94,13 @@ def duration_asize(duration, aac, opus):
     elif len(A) == 125: A += '        '
     elif len(A) == 126: A += '       '
     elif len(A) == 127: A += '      '
+    elif len(A) == 128: A += '     '
     elif len(A) == 130: A += '       '
     elif len(A) == 131: A += '      '
     elif len(A) == 132: A += '     '
     elif len(A) == 133: A += '    '
     #print(len(A), len(O), len(duration))
-    rprint(f'[{ly}]{duration}| {A}| {O}[/{ly}]\n')
+    rprint(f'{duration}[{ly}]| {A}| {O}[/{ly}]\n')
 
 
 def clr_size(name, size):
@@ -134,8 +138,8 @@ def clr_size(name, size):
 
 
 def lens(size):
-    if   len(size) == 62: size += '       '
-    elif len(size) == 63: size += '      '
+    if   len(size) == 66: size += '       '
+    elif len(size) == 67: size += '      '
     elif len(size) == 97: size += '     '
     elif len(size) == 98: size += '    '
     elif len(size) == 99: size += '   '
@@ -197,11 +201,12 @@ def live():
 
 def premier(duration):
     premier = Panel.fit(f'[{br}]PREMIERING NOW[/{br}]', border_style = br)
-    duration = f'[{w}]DURATION:[/{w}] ([i {lg}]{duration}[/i {lg}])'
+    duration = f'[{w}]DURATION:[/{w}][{ly}] ([i {lg}]{duration}[/i {lg}])[/{ly}]'
     rprint(f'{duration}')
     rprint(Padding(premier, (0, 30)))
 
 def liveFormats(formats):
+    global fList
     fList = [i for i in formats if i is not None]
     LL = len(fList)
 
@@ -230,19 +235,35 @@ def liveFormats(formats):
 
 
 def checker(listt, size, item, name):
+    def qnf(n):
+        qnotf = f'[s {r}]{name}[/s {r}]'
+        if item == '':
+            return f'[{lg}]{n}[/{lg}]'
+        else:
+            return f'{qnotf} [{lg}]{n}[/{lg}]'
+
     if size:
         result = bool([i for i in listt if i.endswith(item)])
-        if result:
-            return name
+        if result and item != '':
+            return f'[{lg}]{name}[/{lg}]'
         else:
             if bool([i for i in listt if i.endswith('480')]):
-                return f'[s {r}]{name}[/s {r}] 480p'
+                return qnf('480p (DEFAULT)')
             elif bool([i for i in listt if i.endswith('360')]):
-                return f'[s {r}]{name}[/s {r}] 360p'
+                return qnf('360p')
             else:
-                return f'[s {r}]{name}[/s {r}] best'
+                return qnf('best')
     else:
-        return name
+        result = bool([i for i in listt if item in i])
+        if result and item != '':
+            return f'[{lg}]{name}[/{lg}]'
+        else:
+            if bool([i for i in listt if '480p' in i]):
+                return qnf('480p (DEFAULT)')
+            elif bool([i for i in listt if '360p' in i]):
+                return qnf('360p')
+            else:
+                return qnf('best')
 
 
 def play(choice, size, mkv, video_quality, playonly):
@@ -266,130 +287,134 @@ def play(choice, size, mkv, video_quality, playonly):
                 return '94/93/best'
             
 
+    def qqquality(mkvC, mp4C, name, LQ):
+        if size:
+            if mkv:
+                qInfo = checker(video_quality, size, mkvC, name)
+                vid = video_quality.get(mkvC)
+                if name == 'm4a' or name == 'Opus' or name == 'Best Opus':
+                    qPlay = f'{vid}/{bq()}'
+                else:
+                    qPlay = f'{vid}+{opus}/{bq()}'
+            else:
+                qInfo = checker(video_quality, size, mp4C, name)
+                vid = video_quality.get(mp4C)
+                if name == 'm4a' or name == 'Opus' or name == 'Best Opus':
+                    qPlay = f'{vid}/{bq()}'
+                else:
+                    qPlay = f'{vid}+{aac}/{bq()}'
+        else:
+            qInfo = checker(fList, size, name, name)
+            qPlay = f'{LQ}/{bq()}'
+        return qInfo, qPlay
+
+
+    if not choice:
+        def na(n): return f'[{lg}]{n}[/{lg}]'
+
+        n1 = na(1); n2 = na(2); n3 = na(3); n4 = na(4); n7 = na(7); n9 = na('[9]'); n0 = na('[0]')
+        s = f'[{ly}]-[/{ly}]' ; nb = na('b'); nw = na('w')
+        rprint(f'{nb}[{br}]est {s} {nw}orst {s} {n1}080p {s} {n2}40p {s} {n3}60p {s} {n4}80p {s} {n7}20p {s} {n9}1440p {s} {n0}2160p [/{br}]')
+
+        try:
+            try:
+                def userChoice():
+                    if mkv:
+                        userC = rinput(f'[{w}]QUALITY:[{b}](mkv)[/{b}][{ly}] > ')
+                    else:
+                        userC = rinput(f'[{w}]QUALITY:[{b}](twice for mkv)[/{b}][{ly}] > ')
+                    return userC
+                choice = func_timeout(20, lambda: userChoice())
+            except FunctionTimedOut:
+                print('')
+            if choice:
+                if choice.count(choice[0]) == 2 and len(choice) == 2:
+                    choice = choice[0]
+                    cl = ['a', 'o', 'O', 'b', 'w', '1', '2', '3', '4', '7', '8', '9', '0']
+                    if choice in cl:
+                        mkv = True
+
+        except KeyboardInterrupt:
+            print(''); usr_err()
+            exit()
+
     if choice == 'a':
-        if aac:
-            qInfo = 'Audio'
-        else:
-            qInfo = f'[s {r}]AAC[/s {r}] 480p (DEFAULT)'
-        qPlay = aac
+        chkd = qqquality('aac', 'aac', 'm4a', '00')
+        qInfo = chkd[0] ; qPlay = chkd[1]
+
     elif choice == 'o':
-        if opus:
-            qInfo = 'Opus'
-        else:
-            qInfo = f'[s {r}]OPUS[/s {r}] 480p (DEFAULT)'
-        qPlay = opus
+        chkd = qqquality('opus', 'opus', 'Opus', '00')
+        qInfo = chkd[0] ; qPlay = chkd[1]
 
     elif choice == 'O':
-        if opus:
-            qInfo = 'Best Opus'
-        else:
-            qInfo = f'[s {r}]OPUS[/s {r}] 480p (DEFAULT)'
-        qPlay = 'bestaudio[ext=webm]'
+        chkd = qqquality('best_opus', 'best_opus', 'Best Opus', '00')
+        qInfo = chkd[0] ; qPlay = chkd[1]
 
     elif choice == 'b':
-        qInfo = 'Best'
+        qInfo = f'[{lg}]Best[/{lg}]'
         if mkv:
-            qPlay = 'bestvideo[ext=webm]+bestaudio[ext=webm]'
+            qPlay = 'bestvideo[ext=webm]+bestaudio[ext=webm]/best'
         else:
             qPlay = 'best'
 
+    elif choice == 'c':
+        print('') ; exit()
+
     elif choice == 'w': 
         qInfo = f'[{r}]Worst[/{r}]'
         if mkv:
             qPlay = 'worstvideo[ext=webm]+worstaudio[ext=webm]/worst'
         else:
-            qPlay = 'worst'
+            qPlay = 'worstvideo[ext=mp4]+worstaudio[ext=m4a]/worst'
 
     elif choice == '1' or choice == '8':
-        if mkv:
-            qInfo = checker(video_quality, size, 'mkv_1080', '1080p')
-            vid = video_quality.get('mkv_1080')
-            qPlay = f'96/{vid}+{opus}/{bq()}'
-        else:
-            qInfo = checker(video_quality, size, 'mp4_1080', '1080p')
-            vid = video_quality.get('mp4_1080')
-            qPlay = f'96/{vid}+{aac}/{bq()}'
+        chkd = qqquality('mkv_1080', 'mp4_1080', '1080p', '96')
+        qInfo = chkd[0] ; qPlay = chkd[1]
 
     elif choice == '2': 
-        if mkv:
-            qInfo = checker(video_quality, size, 'mkv_240', '240p')
-            vid = video_quality.get('mkv_240')
-            qPlay = f'92/{vid}+{opus}/{bq()}'
-        else:
-            qInfo = checker(video_quality, size, 'mp4_240', '240p')
-            vid = video_quality.get('mp4_240')
-            qPlay = f'92/{vid}+{aac}/{bq()}'
+        chkd = qqquality('mkv_240', 'mp4_240', '240p', '92')
+        qInfo = chkd[0] ; qPlay = chkd[1]
 
     elif choice == '3': 
-        if mkv:
-            qInfo = checker(video_quality, size, 'mkv_360', '360p')
-            vid = video_quality.get('mkv_360')
-            qPlay = f'93/{vid}+{opus}/{bq()}'
-        else:
-            qInfo = checker(video_quality, size, 'mp4_360', '360p')
-            vid = video_quality.get('mp4_360')
-            qPlay = f'93/{vid}+{aac}/{bq()}'
+        chkd = qqquality('mkv_360', 'mp4_360', '360p', '93')
+        qInfo = chkd[0] ; qPlay = chkd[1]
 
     elif choice == '4': 
-        qInfo = '480p'
-        if mkv:
-            qInfo = checker(video_quality, size, 'mkv_480', '480p')
-            vid = video_quality.get('mkv_480')
-            qPlay = f'94/{vid}+{opus}/{bq()}'
-        else:
-            qInfo = checker(video_quality, size, 'mp4_480', '480p')
-            vid = video_quality.get('mp4_480')
-            qPlay = f'94/{vid}+{aac}/{bq()}'
+        chkd = qqquality('mkv_480', 'mp4_480', '480p', '94')
+        qInfo = chkd[0] ; qPlay = chkd[1]
 
     elif choice == '7':
-        if mkv:
-            qInfo = checker(video_quality, size, 'mkv_720', '720p')
-            vid = video_quality.get('mkv_720')
-            qPlay = f'95/{vid}+{opus}/{bq()}'
-        else:
-            qInfo = checker(video_quality, size, 'mp4_720', '720p')
-            vid = video_quality.get('mp4_720')
-            qPlay = f'95/{vid}+{aac}/{bq()}'
+        chkd = qqquality('mkv_720', 'mp4_720', '720p', '95')
+        qInfo = chkd[0] ; qPlay = chkd[1]
 
     elif choice == '9':
-        if mkv:
-            qInfo = checker(video_quality, size, 'mkv_1440', '1440p')
-            vid = video_quality.get('mkv_1440')
-            qPlay = f'{vid}+{opus}/{bq()}'
-        else:
-            qInfo = checker(video_quality, size, 'mp4_1440', '1440p')
-            vid = video_quality.get('mp4_1440')
-            qPlay = f'{vid}+{aac}/{bq()}'
+        chkd = qqquality('mkv_1440', 'mp4_1440', '1440p', '00')
+        qInfo = chkd[0] ; qPlay = chkd[1]
 
     elif choice == '0':
-        if mkv:
-            qInfo = checker(video_quality, size, 'mkv_2160', '2160p')
-            vid = video_quality.get('mkv_2160')
-            qPlay = f'{vid}+{opus}/{bq()}'
-        else:
-            qInfo = checker(video_quality, size, 'mp4_2160', '2160p')
-            vid = video_quality.get('mp4_2160')
-            qPlay = f'{vid}+{aac}/{bq()}'
+        chkd = qqquality('mkv_2160', 'mp4_2160', '2160p', '00')
+        qInfo = chkd[0] ; qPlay = chkd[1]
 
     else: 
         qPlay = f'{bq()}'
+        choice = None
 
+    
     if choice:
-        rprint(f'[{w}]PLAYING:[/{w}] [{lg}]{qInfo}[/{lg}]')
+        rprint(f'[{w}]PLAYING:[/{w}] {qInfo}')
     else:
-        if bool([i for i in video_quality if i.endswith('480')]):
-            rprint(f'[{w}]PLAYING:[/{w}] [{lg}]480p (DEFAULT)[/{lg}]')
-        elif bool([i for i in video_quality if i.endswith('360')]):
-            rprint(f'[{w}]PLAYING:[/{w}] [{lg}]360p[/{lg}]')
-        else:
-            rprint(f'[{w}]PLAYING:[/{w}] [{lg}]best[/{lg}]')
+        chkd = qqquality('', '', '', '')
+        qInfo = chkd[0]
+        rprint(f'[{w}]PLAYING:[/{w}] {qInfo}')
 
-    if not playonly:
+    if playonly:
+        rprint(f'[{br}]PLAYONLY:[/{br}] [{lg}]Enabled[/{lg}]')
+    else:
         if size:
             if choice == 'o' or choice == 'O':
                 rprint(f'[{w}]OUTPUT:[/{w}] [{b}]opus[/{b}]')
             elif choice == 'a':
-                rprint(f'[{w}]OUTPUT:[/{w}] [{b}]aac[/{b}]')
+                rprint(f'[{w}]OUTPUT:[/{w}] [{b}]m4a[/{b}]')
             elif mkv:
                 rprint(f'[{w}]OUTPUT:[/{w}] [{b}]mkv[/{b}]')
             else:
@@ -400,7 +425,7 @@ def play(choice, size, mkv, video_quality, playonly):
             else:
                 rprint(f'[{w}]OUTPUT:[/{w}] [{yo}]mp4[/{yo}]')
 
-    return qPlay
+    return qPlay, choice, mkv
 
 
 
