@@ -1,17 +1,17 @@
 #!/usr/bin/python
 
 # (yw) YOUTUBE-WATCH (Prayz Jomba)
-#           >>>VERSION (0.6.2)<<<
+#           >>>VERSION (0.6.3)<<<
 #
 
 # APP
-ver = '0.6.2'
+ver = '0.6.3'
 apn = 'yWatch'
 
 
 # IMPORTS
 import os, subprocess
-from ywatch import userInputs, dataprocess, menu
+from ywatch import userInputs, menu
 from datetime import date
 
 
@@ -19,12 +19,17 @@ from datetime import date
 userIn  = userInputs.args
 user_q  = userIn.Quality
 
+# VERSION
+if userIn.version:
+    menu.version(apn, ver)
+    exit()
+
+from ywatch import dataprocess
 
 # DATA FILE
 dataFile = dataprocess.dataFile
 link = dataprocess.link
 
-
 # FULL SCREEN
 if userIn.fullscreen: #-f
     fs = '-fs'
@@ -87,11 +92,6 @@ def stream():
     dataprocess.stream(link, quality, file, resume, userIn.playonly, fs)
 
 
-# VERSION
-if userIn.version:
-    menu.version(apn, ver)
-    exit()
-
 # CLEAR SCREEN
 if not userIn.disable_clear: #-c
     os.system('clear')
@@ -135,6 +135,11 @@ if userIn.size:
 size_true = size_true()
 quality = menu.play(userIn.Quality, size_true, userIn.mkv, video_quality(), userIn.playonly)
 
+if not user_q:
+    user_q = quality[1]
+    userIn.mkv = quality[2]
+quality = quality[0]
+
 
 # DATE
 date  = date.today()
@@ -154,29 +159,30 @@ os.chdir(folder)
 x = 1
 
 #AUDIO DIR
-if user_q == 'a' or user_q == 'o' or user_q == 'O' and size_true:
-    if not os.path.isdir('Audio'):
-        os.makedirs('Audio') 
-    os.chdir('Audio')
+if user_q == 'a' or user_q == 'o' or user_q == 'O':
+    if size_true:
+        if not os.path.isdir('Audio'):
+            os.makedirs('Audio') 
+        os.chdir('Audio')
 
-    if user_q == 'a':
-        file = f'{title}.aac'
-        if os.path.isfile(file):
-            while os.path.isfile(f'{title}{x}.aac'):
-                x += 1
-            file = f'{title}{x}.aac'
-    elif user_q == 'o':
-        file = f'{title}.opus'
-        if os.path.isfile(file):
-            while os.path.isfile(f'{title}{x}.opus'):
-                x += 1
-            file = f'{title}{x}.opus'
-    else:
-        file = f'{title} (Best Opus).opus'
-        if os.path.isfile(file):
-            while os.path.isfile(f'{title}{x} (Best Opus).opus'):
-                x += 1
-            file = f'{title}{x} (Best Opus).opus'
+        if user_q == 'a':
+            file = f'{title}.m4a'
+            if os.path.isfile(file):
+                while os.path.isfile(f'{title}{x}.m4a'):
+                    x += 1
+                file = f'{title}{x}.m4a'
+        elif user_q == 'o':
+            file = f'{title}.opus'
+            if os.path.isfile(file):
+                while os.path.isfile(f'{title}{x}.opus'):
+                    x += 1
+                file = f'{title}{x}.opus'
+        else:
+            file = f'{title} (Best Opus).opus'
+            if os.path.isfile(file):
+                while os.path.isfile(f'{title}{x} (Best Opus).opus'):
+                    x += 1
+                file = f'{title}{x} (Best Opus).opus'
 
 elif userIn.mkv:
     file = f'{title}.mkv'
@@ -230,7 +236,7 @@ if file.endswith('ts'):
 
 #OPEN
 if userIn.watch:
-    subprocess.Popen(['mpv', fs, file, '--loop-playlist', '--player-operation-mode=pseudo-gui'])
+    subprocess.Popen(['mpv', fs, file, '--loop-playlist', '--player-operation-mode=pseudo-gui', '--autofit-larger=30%'])
 
 
 exit()
